@@ -1,13 +1,13 @@
 /* ISC license. */
 
 #include <stdint.h>
+
 #include <skalibs/bytestr.h>
 #include <skalibs/sha256.h>
 #include "sha256-internal.h"
 
 void sha256_final (SHA256Schedule *ctx, char *digest)
 {
-  unsigned int i = 0 ;
   unsigned char *p = (unsigned char *)digest ;
   uint32_t bits[2] = { ctx->bits[0], ctx->bits[1] } ;
 
@@ -21,7 +21,7 @@ void sha256_final (SHA256Schedule *ctx, char *digest)
   sha256_feed(ctx, T8(bits[0]>>16)) ;
   sha256_feed(ctx, T8(bits[0]>>8)) ;
   sha256_feed(ctx, T8(bits[0])) ;
-  for (; i < 8 ; i++)
+  for (uint32_t i = 0 ; i < 8 ; i++)
   {
     *p++ = T8(ctx->buf[i]>>24) ;
     *p++ = T8(ctx->buf[i]>>16) ;
