@@ -5,6 +5,8 @@
 
 size_t byte_chr (char const *s, size_t n, int c)
 {
-  void *p = memchr(s, c, n) ;
+  void *p ;
+  if (!n) return 0 ;
+  p = memchr(s, c, n) ;
   return p ? (char *)p - s : n ;
 }
