@@ -1,13 +1,14 @@
 /* ISC license. */
 
+#include <ctype.h>
+
 #include <skalibs/bytestr.h>
 
 void case_uppers (char *s)
 {
-  unsigned char const d = 'a' - 'A' ;
   while (*s)
   {
-    if (('a' <= *s) && (*s <= 'z')) *s -= d ;
-    ++s ;
+    int c = toupper(*s) ;
+    *s++ = (unsigned char)c ;
   }
 }
