@@ -2,4 +2,4 @@
 
 #include <skalibs/cdb.h>
 
-struct cdb const cdb_zero = CDB_ZERO ;
+cdb const cdb_zero = CDB_ZERO ;
