@@ -9,7 +9,7 @@
 
 int ltm64_from_sysclock (uint64_t *u)
 {
-  tai_t t = { .x = *u + 10U } ;
+  tai t = { .x = *u + 10U } ;
   return ltm64_from_tai(u, &t) ;
 }
 
