@@ -2,7 +2,7 @@
 
 #include <skalibs/tai.h>
 
-double tain_frac (tain_t const *t)
+double tain_frac (tain const *t)
 {
   return t->nano * 0.000000001 ;
 }
