@@ -3,7 +3,7 @@
 #include <skalibs/uint64.h>
 #include <skalibs/tai.h>
 
-int tain_to_millisecs (tain_t const *a)
+int tain_to_millisecs (tain const *a)
 {
   if (a->sec.x > (uint64_t)2147483) return -1 ;
   if ((a->sec.x == (uint64_t)2147483) && (a->nano > 646000000U)) return -1 ;
