@@ -6,7 +6,7 @@
 #include <errno.h>
 #include <skalibs/tai.h>
 
-int time_from_tai_relative (time_t *u, tai_t const *t)
+int time_from_tai_relative (time_t *u, tai const *t)
 {
 #if SKALIBS_SIZEOFTIME < 8
   if ((t->x >> 32) && (t->x >> 32) != 0xffffffffUL)
