@@ -6,7 +6,11 @@
 int open_truncatb (int dirfd, char const *name)
 {
   int fd = open_truncat(dirfd, name) ;
-  if (fd < 0) return -1 ;
-  if (ndelay_off(fd) < 0) return -1 ;
+  if (fd == -1) return -1 ;
+  if (ndelay_off(fd) == -1)
+  {
+    fd_close(fd) ;
+    return -1 ;
+  }
   return fd ;
 }
