@@ -2,7 +2,7 @@
 
 #include <skalibs/unixmessage.h>
 
-int unixmessage_sender_getfd (unixmessage_sender_t const *b)
+int unixmessage_sender_getfd (unixmessage_sender const *b)
 {
   return b->fd ;
 }
